Package: algaeClassify
Title: Tools to Query the 'Algaebase' Online Database, Standardize
        Phytoplankton Taxonomic Data, and Perform Functional Group
        Classifications
Version: 2.0.6
Date: 2026-05-10
Authors@R: c(person("Vijay","Patil",email=c("vij.patil@gmail.com"),role=c("aut","cre")),
		   person("Torsten","Seltmann",role="aut"),
		   person("Nico","Salmaso",role="aut"),
		   person("Orlane","Anneville",role="aut"),
		   person("Marc","Lajeunesse",role="aut"),
		   person("Dietmar","Straile",role="aut"))
Author: Vijay Patil [aut, cre],
  Torsten Seltmann [aut],
  Nico Salmaso [aut],
  Orlane Anneville [aut],
  Marc Lajeunesse [aut],
  Dietmar Straile [aut]
Maintainer: Vijay Patil <vij.patil@gmail.com>
Description: Functions that facilitate the use of accepted taxonomic nomenclature, collection of
	functional trait data, and assignment of functional group classifications to phytoplankton
	species. Possible classifications include Morpho-functional group (MFG; Salmaso et al. 2015 
	<doi:10.1111/fwb.12520>) and CSR (Reynolds 1988; Functional morphology and the 
	adaptive strategies of phytoplankton. In C.D. Sandgren (ed). Growth and reproductive 
	strategies of freshwater phytoplankton, 388-433. Cambridge University Press, New York). 
	Versions 2.0.0 and later includes new functions for querying the 
	'algaebase' online taxonomic database (www.algaebase.org), however these functions require
	a valid API key that must be acquired from the 'algaebase' administrators. 
	Note that none of the 'algaeClassify' authors are affiliated with 'algaebase' in any way. Taxonomic 
	names can also be checked against a variety of taxonomic databases using 
	the 'Global Names Resolver' service via its API (<https://resolver.globalnames.org/api>). In addition,
	currently accepted and outdated synonyms, and higher taxonomy, can be extracted for lists of
	species from the 'ITIS' database via its JSON web service API.
	The 'algaeClassify' package is a product of the GEISHA (Global Evaluation of the Impacts of 
	Storms on freshwater Habitat and Structure of phytoplankton Assemblages), funded by CESAB 
    (Centre for Synthesis and Analysis of Biodiversity) and the U.S. Geological Survey John Wesley Powell Center for
	Synthesis and Analysis, with data and other support provided by members of GLEON 
	(Global Lake Ecology Observation Network). 
	DISCLAIMER: This software has been approved for release by the 
	U.S. Geological Survey (USGS). Although the software has been subjected to rigorous review, 
	the USGS reserves the right to update the software as needed pursuant to further analysis and 
	review. No warranty, expressed or implied, is made by the USGS or the U.S. Government as to the 
	functionality of the software and related material nor shall the fact of release constitute 
	any such warranty. Furthermore, the software is released on condition that neither the USGS 
	nor the U.S. Government shall be held liable for any damages resulting from its authorized 
	or unauthorized use.
Depends: R (>= 4.4.0)
URL: https://doi.org/10.5066/F7S46Q3F
Imports: lubridate, stats, curl, jsonlite, methods
License: CC0
Encoding: UTF-8
LazyData: true
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-11 00:22:47 UTC; vpatil
Repository: CRAN
Date/Publication: 2026-05-11 05:10:07 UTC
