# Generated by roxygen2: do not edit by hand

export(accum)
export(algaebase_genus_search)
export(algaebase_output_parse)
export(algaebase_search_df)
export(algaebase_species_search)
export(bestmatch)
export(date_mat)
export(genus_search_itis)
export(genus_species_extract)
export(get_apikey)
export(get_apikey_fromfile)
export(gnr_df)
export(gnr_simple)
export(itis_search_df)
export(mean_naomit)
export(mfg_csr_convert)
export(mfg_csr_convert_df)
export(phyto_ts_aggregate)
export(sampeff)
export(set_algaebase_apikey_header)
export(species_search_itis)
export(species_to_mfg)
export(species_to_mfg_df)
export(traits_to_csr)
export(traits_to_csr_df)
export(traits_to_mfg)
export(traits_to_mfg_df)
importFrom(methods,is)
