#' MFG-CSR correspondence based on CSR-trait relationships in Reynolds et al. 1988
#' and MFG-trait relationships in Salmaso et al. 2015
#'
#' @format A data frame with columns:
#' \describe{
#'  \item{MFG}{full MFG name from Salmaso et al. 2015}
#'  \item{CSR}{CSR classification including intermediate classes}
#' }
#'
#' @docType data
#'
#' @usage data(mfg_csr_library)
#'
#' @keywords datasets
#'
"mfg_csr_library"